<?php

/**
 * License Info
 *
 * This is a test File docblock
 *
 * @author Ralph Schindler
 */

namespace LaminasTest\Code\Reflection\TestAsset;

/**
 * This is a sample class docblock
 *
 * blah
 */
class TestSampleClass extends \ArrayObject
{

}
